@@ -92,6 +92,26 @@ class MMSClient(BaseClient):
         df.index = df.index.map(str)
         df['id'] = df['id'].apply(str)
         return df
+    
+    def get_cost_recovery_meters(self):
+        """
+        :return: A dataframe of cost recovery readings (cost_recovery)
+        """
+        
+        query = sql.SQL("SELECT code, "
+                        "       name, "
+                        "       device_id as id, "
+                        "       cost_recovery "
+                        "FROM meters "
+                        "INNER JOIN devices d on meters.device_id = d.id "
+                        "WHERE cost_recovery=1")
+        df = pd.read_sql(query,
+                         con=self.conn,
+                         index_col='code')
+        df.index = df.index.map(str)
+        df['id'] = df['id'].apply(str)
+        return df
+        
 
     def get_registers_for_meter(self, device_model_id):
         """
@@ -127,7 +147,7 @@ class MMSClient(BaseClient):
                 # No device record returned
                 raise LookupError("No meter found for device {0}"
                                   .format(device_id))
-
+                
     def add_simulation(self, sim_name):
         """
         :param string sim_name: Name of simulation (Unique in DB)
