@@ -44,11 +44,12 @@ def get_secrets(system_name: str, parameter_names: List[str],
         else:
             params[p.rsplit('/', 1)[1]] = None
 
-    missing_params = [p for p in params if p is None]
+    missing_params = [p for p, v in params.items() if v is None]
     if missing_params:
-        logger.debug(f"Getting secrets {missing_params} from AWS Param store")
+        full_param_names = [f"/{system_name}/{p}" for p in missing_params]
+        logger.debug(f"Getting secrets {full_param_names} from AWS Param store")
         ssm = boto3.client('ssm')
-        response = ssm.get_parameters(Names=missing_params)
+        response = ssm.get_parameters(Names=full_param_names)
         for p in response['Parameters']:
             name = p['Name'].rsplit('/', 1)[1]
             logger.debug("AWS Param {} is in params dict {}"
